==> exo.jcr.component.ext-1.9.3-sources.jar: org/exoplatform/services/jcr/ext/app/SessionProviderService.java <==
/*
 * Copyright (C) 2003-2007 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.services.jcr.ext.app;

import org.exoplatform.services.jcr.ext.common.SessionProvider;

/**
 * Created by The eXo Platform SAS        .
 * Session providers holder component 
 * @author Gennady Azarenkov
 * @version $Id: SessionProviderService.java 13869 2008-05-05 08:40:10Z pnedonosko $
 */

public interface SessionProviderService {
  
  /**
   * @param key
   * @param sessionProvider
   */
  void setSessionProvider(Object key, SessionProvider sessionProvider);
  
  /**
   * @param key
   * @return session provider
   */
  SessionProvider getSessionProvider(Object key);
  
  /**
   * @param key
   * @return system session provider
   */
  SessionProvider getSystemSessionProvider(Object key);  
  
  /**
   * Removes the session provider
   * @param key
   */
  void removeSessionProvider(Object key);
}

==> exo.jcr.component.ext-1.10.3-sources.jar: org/exoplatform/services/jcr/ext/app/SessionProviderService.java <==
/*
 * Copyright (C) 2003-2007 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.services.jcr.ext.app;

import org.exoplatform.services.jcr.ext.common.SessionProvider;

/**
 * Created by The eXo Platform SAS . Session providers holder component
 * 
 * @author Gennady Azarenkov
 * @version $Id: SessionProviderService.java 13869 2008-05-05 08:40:10Z pnedonosko $
 */

public interface SessionProviderService {

  /**
   * @param key
   * @param sessionProvider
   */
  void setSessionProvider(Object key, SessionProvider sessionProvider);

  /**
   * @param key
   * @return session provider
   */
  SessionProvider getSessionProvider(Object key);

  /**
   * @param key
   * @return system session provider
   */
  SessionProvider getSystemSessionProvider(Object key);

  /**
   * Removes the session provider
   * 
   * @param key
   */
  void removeSessionProvider(Object key);
}
